<template>
    <div class="_auth_page">
        <div class="container">
            <div class="login_wrapper w-tab mt-4 mb-0">
              <h1 class="mb-4">Sign-In</h1>
                <v-form ref="form" @submit.prevent="authLogin">
                  <div class="flex relative">
                    <v-text-field
                        label="Mobile No. or E-Mail Address"
                        v-model="auth.mobile"
                        name="mobile"
                        autofocus
                        outline
                        type="text"
                        class="mb-20"
                    ></v-text-field>
                    <v-btn v-if="forgot_password" :loading="resendLoading" @click="resendCode(auth.mobile)" class="fcode">Send Code</v-btn>
                  </div>
                    <div v-if="forgot_password" class="mb-20">
                        <v-text-field
                            outline
                            label="Enter Verification Code"
                            type="tel"
                            autofocus
                            :rules="validateRule"
                            v-model="auth.fp_otp"
                            class="mb-20"
                        ></v-text-field>
                        <v-text-field
                            outline
                            label="New Password"
                            type="password"
                            :rules="validateRule"
                            v-model="auth.fp_password"
                            class="mb-3"
                        ></v-text-field>
                        <v-btn
                            @click="forgotPassword"
                            class="m-0 mb-20"
                            large
                            :loading="loading"
                            block
                            color="secondary"
                            type="button"
                            name="auth_login"
                        >Reset Password</v-btn>
                    </div>
                    <div v-else>
                        <div class="relative _dg" v-if="!forgot_password_screen">
                            <v-text-field
                                label="Password"
                                outline
                                v-model="auth.password"
                                hint="Min. 6 character"
                                name="password"
                                :rules="validateRule"
                                type="password"
                                class="mb-20"
                            >
                            </v-text-field>
                            <div class="_fp pointer" @click="forgot_password_screen = true">Reset Password</div>
                        </div>
                        <v-btn
                            v-if="!forgot_password_screen"
                            class="m-0 mb-20"
                            large
                            :loading="loading"
                            block
                            color="primary"
                            type="submit"
                            name="auth_login"
                        >Sign In</v-btn>
                        <v-btn
                            v-if="forgot_password_screen"
                            @click="forgotPasswordCheck"
                            class="m-0 mb-20"
                            large
                            :loading="loading"
                            block
                            color="secondary"
                            type="button"
                        >Send Verification Code</v-btn>
                    </div>
                    <div v-if="forgot_password">
                        <v-btn
                            @click="loginScreen"
                            class="m-0 mb-20"
                            large
                            block
                            color="secondary"
                            type="button"
                            outline
                            name="auth_login"
                        > Back to Login</v-btn>
                    </div>
                        <p class="_auth_desc" v-if="!forgot_password">
                            By continuing, you agree to Cardboard's Conditions of Use and Privacy Notice.
                        </p>
                </v-form>

            </div>
            <div class="text-center mb-5 mt-3">
                <p>New to Cardboard Baling Wire?</p>
                <v-btn
                    large
                    color="secondary"
                    block
                    :to="'/account/register' + ($route.query.back ? '?back=' + $route.query.back : '')"
                    v-if="!forgot_password"
                >Register a New Account</v-btn>

            </div>
        </div>
    </div>
</template>
<script>

export default {
    layout: 'auth',
    asyncData (context) {
        var store = context.store;
        return {
          user: store.state.customer
        }
    },
    data () {
        return {
            forgot_password_screen: false,
            user: [],
            mobileMask: 'phone',
            forgot_password: false,
            resendLoading: false,
            validate: true,
            auth: [],
            loading: false,
            mobileRules: [
                v => !!v && v.length >= 10 || 'Mobile must be 10 digit number'
            ],
            validateRule: [
                v => !!v || 'This field is required'
            ]
        }
    },
    beforeCreate() {
      // axios.get(this.$store.state.api_domain + '?comp=process&action=checkBroker', {withCredentials:true}).then((res) => {
      //   if (res.data.active == 1 && res.data.id_customer) {
      //       this.$router.push('/customer/orders');
      //   }
      // });
    },
    created () {
    },
    watch: {
      user: function (obj) {

        if (obj && obj.id) {

            this.$router.push('/account/orders');

        }

      }
    },
    methods: {
        checkAuth: function () {

            if (this.$store.state.customer && this.$store.state.customer.id) {

                this.$router.push('/account/orders');

            }
        },
        getToLink: function () {
            return '/account/register';
        },
        loginScreen: function () {
            this.forgot_password = false;
        },
        forgotPasswordCheck: function () {
            if (!this.auth.mobile) {
                alert('Please Add Mobile Number or Email Address To Get Your Password Reset Code');
            }
            if (this.auth.mobile) {
                if (this.auth.mobile.length < 10) {
                    alert('Mobile number should be of 10 digits');
                } else {
                    this.forgot_password = true;
                    var form_data = new FormData();
                    form_data.append('mobile', this.auth.mobile);
                    form_data.append('forgotPass', 'fp');
                    form_data.append('identifier', 'forgot');
                    this.$axiosx.post('api?comp=process&action=sendOTP', form_data)
                    .then((res) => {
                        alert(res.data.message);
                    });
                }
            }
        },
        forgotPassword: function () {
            if (this.$refs.form.validate()) {
                this.loading = true;
                var form_data = new FormData();
                form_data.append('mobile', this.auth.mobile);
                form_data.append('code', this.auth.fp_otp);
                form_data.append('identifier', 'forgot');
                form_data.append('password', this.auth.fp_password);

                this.$axiosx.post('api?comp=process&action=forgot_password', form_data).then((res) => {
                    if (res.data.status == 'success') {
                        this.auth.fp_otp = '';
                        this.auth.fp_password = '';
                        alert(res.data.message);
                        window.location.reload(true);
                        this.forgot_password = false;
                    }

                    if (res.data.status == 'error') {
                        alert(res.data.message);
                    }
                    this.loading = false;
                });
            }
        },
        resendCode: function(mobile) {
            this.resendLoading = true;
            var form_data = new FormData();
            form_data.append('mobile', this.auth.mobile);
            this.$axiosx.post('api?comp=process&action=resendCode', form_data, {withCredentials: true}).then((res) => {
                this.resendLoading = false;
                if (res.data.status == 'success') {
                    alert(res.data.message);
                }
                if (res.data.status == 'error') {
                    alert(res.data.message);
                }
                this.resendLoading = false;
            });
        },
        authLogin: function () {
            this.$store.commit('hideSnackBar');
            if (this.$refs.form.validate()){

                this.loading = true;
                var form_data = new FormData();
                form_data.append('mobile', this.auth.mobile);
                form_data.append('password', this.auth.password);

                this.$axiosx.post('api?comp=process&action=authLogin', form_data)
                .then((res) => {
                    this.loading = false;

                    if (res.data.status == 'success') {
                        this.$store.commit('setCustomer', res.data.customer);
                        var t = this;
                        if (
                            this.$route.query.back
                        ) {

                            this.$router.push('/' + this.$route.query.back);

                        } else {

                            this.$router.push('/account/orders');

                        }
                    }

                    if (res.data.status == 'error') {
                        alert(res.data.message);
                    }
                }).catch((e) => {
                    console.log(e);
                    this.loading = false;
                });
            }
        }
    },
    head() {
        return {
            title: 'Login For Customers & Waste Brokers | Balingwiredirect.com',
            meta: [
                {hid: 'description', name: 'description', content: 'Login For Customers & Waste Brokers'},
                {hid: 'keywords', name: 'keywords', content: 'baling wire direct login, customers login at baling wire direct'}
            ]
        }
    }
}
</script>
